/*
 *  Copyright (C) 2005 Janusz Dziemidowicz (rraptorr@nails.eu.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*!
 * \file dune2.h
 * \author Janusz Dziemidowicz
 * \brief Dune 2 PAK format support header file.
 */

#ifndef _DUNE2_H_
#define _DUNE2_H_

#define _GNU_SOURCE

#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>

#include <pthread.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include "tree.h"
#include "fusepak.h"

/*!
 * \brief One entry (file) inside of Dune 2 PAK file.
 *
 * This structures describes one entry inside of Dune 2 PAK file.
 */
struct dune2_entry {
	/*!
	 * \brief Offset of file inside of PAK file.
	 *
	 * This field defines at what offset the file described by \c
	 * dune2_entry can be found inside of PAK file.
	 */
	uint32_t offset;

	/*!
	 * \brief Filename.
	 *
	 * Name of the file. Zero terminated string of unspecified
	 * length.
	 */
	char *filename;
};

/*!
 * \brief Structure \c fusepak_format describing Dune 2 PAK format.
 */
extern struct fusepak_format fusepak_dune2;

#endif				// _DUNE2_H_
