/*
 *  Copyright (C) 2005 Janusz Dziemidowicz (rraptorr@nails.eu.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*!
 * \file main.c
 * \author Janusz Dziemidowicz
 * \brief Main program function.
 */

#include <stdlib.h>
#include <stdio.h>

#include "fusepak.h"

/*!
 * \brief Flag indicating wheter we should run in quiet mode (0 - no,
 * all other values - yes).
 */
int quiet;

/*!
 * \brief Main function.
 */
int main(int argc, char *argv[])
{
	char **nargv;
	int nargc, i, j, ret;
	struct fusepak_format *format;

	if (argc < 3) {
		fprintf
		    (stderr,
		     "Usage: %s <archive_file> <mount_point> [<options>] [<FUSE library options>]\n\n",
		     argv[0]);
		fprintf(stderr, "Available options:\n");
		fprintf(stderr,
			"\t-q - quiet mode (print only error messages)\n");
		exit(EXIT_FAILURE);
	}

	for (i = 1; i < argc; i++) {
		if (!strcmp(argv[i], "-q")) {
			quiet = 1;
			for (j = i; j < argc - 1; j++)
				argv[j] = argv[j + 1];
			argc--;
			break;
		}
	}

	ret = fusepak_detect(argv[1], &format);
	/*if (ret < 0) {
	   fprintf(stderr, "unable to read file '%s'\n", argv[1]);
	   exit(EXIT_FAILURE);
	   } */
	if (ret > 0) {
		fprintf(stderr, "format of file '%s' cannot be recognized\n",
			argv[1]);
		exit(EXIT_FAILURE);
	}

	if (!quiet)
		fprintf(stderr, "file '%s' seems to be in %s format\n", argv[1],
			format->format_name);

	nargc = argc - 1;
	nargv = (char **)malloc(nargc * sizeof(char *));

	nargv[0] = argv[0];
	for (i = 1; i < nargc; i++)
		nargv[i] = argv[i + 1];

	return fusepak_main(nargc, nargv);
}
